# -*- coding:utf-8 -*-
import datetime
import logging
import random
import time

import schedule

from SqlServerToMysql.EnvGetter import Config
from SqlServerToMysql.MySqlDriver import MySqlDriver
from SqlServerToMysql.SqlServerDriver import SqlServerDriver

logger = logging.getLogger(__name__)
formatter = logging.Formatter('[%(asctime)s] - [%(levelname)s] - [%(message)s]')
ch = logging.StreamHandler()
ch.setFormatter(formatter)
logger.addHandler(ch)
logger.setLevel(logging.INFO)


def sysnc_db_task():
    logger.info(f"sysnc_db_task starting:{datetime.datetime.now()}")
    # threading.Thread(target=sysnc_db).start()
    sysnc_db()
    logger.info(f"sysnc_db_task ending:{datetime.datetime.now()}")


def sysnc_db():
    # 动态延迟
    devitation_time = Config.DEVIATION_TIME
    try:
        devitation_time = int(devitation_time)
    except Exception as e:
        devitation_time = 120

    # (0-配置时间)之间
    devitation_second = random.randint(0, devitation_time)
    logger.info(f"本次执行延迟时间:{devitation_second}")
    time.sleep(devitation_second)

    mysql_driver = MySqlDriver(Config.MYSQL_CONNECTION)
    mssql_driver = SqlServerDriver(Config.MSSQL_CONNECTION)
    try:
        # 1、获取环境变量中配置的表
        table_im_arrive_str = Config.TABLE_IM_ARRIVE
        # 2、从SQLserver数据库中获取数据
        sqlserver_data_list = mssql_driver.query_all("""SELECT TOP 10 id,bill_no,bill_date,bill_status,create_time
,material_category,customer_name,provider_name
FROM dbo.im_arrive(NOLOCK) 
WHERE id>0
ORDER BY id DESC""")
        # 3、往Mysql中插入数据
        mysql_driver.execute(table_im_arrive_str)
        # 3.1、生成新增语句
        for sqlserver_data in sqlserver_data_list:
            sql = f'''INSERT INTO im_arrive
(`bill_no`,`bill_date`,`bill_status`,`create_time`,`material_category`,`customer_name`,`provider_name`)
VALUES
("{sqlserver_data.bill_no}","{sqlserver_data.bill_date}","{sqlserver_data.bill_status}",NOW()
,"{sqlserver_data.material_category}","{sqlserver_data.customer_name}","{sqlserver_data.provider_name}");'''
            # print(sql)
            mysql_driver.execute(sql)
        # 3.2、删除15天前的数据
        delete_sql = f'''DELETE FROM im_arrive
WHERE create_time < "{datetime.date.today() - datetime.timedelta(days=15)}"'''
        mysql_driver.execute(delete_sql)
        mysql_driver.session.commit()
    finally:
        # 4、close session
        mysql_driver.session.close()
        mssql_driver.session.close()


def run():
    # 每10到15分钟执行一次
    schedule.every(10).to(15).minutes.do(sysnc_db_task)

    while True:
        schedule.run_pending()
        time.sleep(1)


if __name__ == '__main__':
    logger.info("任务开始...")
    run()
