#!/bin/bash
cmd=$1
docker_file_name=$2

# 清除release镜像版本
function clear_release_image() {
  release_image_version=$image_version"_beta"
  docker rmi ${APP_IMAGE}:$release_image_version
  docker rmi ${ALI_IMAGE}:$release_image_version
  echo "成功清除release版本"$release_image_version
}
# 规范镜像版本
function foramt_image_version() {
  release_reg='^release\/.*$'
  if [[ "$CI_COMMIT_REF_NAME" =~  $release_reg ]]; then
    image_version="v"`echo $CI_COMMIT_REF_NAME | grep -Eo '[0-9]+.[0-9]+'`"_beta"
  elif [ "$CI_COMMIT_REF_NAME" == "dev" ]; then
    image_version=$CI_COMMIT_REF_NAME
  else
    image_version="v"`echo $CI_COMMIT_REF_NAME | grep -Eo '[0-9]+.[0-9]+'`
  fi
  if [[ $image_version == "v" ]] || [[ $image_version == "v_beta" ]]; then
    echo "修正后的镜像版本有误:"$image_version",原版本为:"$CI_COMMIT_REF_NAME
    exit 1
  fi
  echo "版本:"$CI_COMMIT_REF_NAME"成功修正为:"$image_version
}
# 写入版本号
function log_version() {
  now_time=`date +%Y%m%d_%H%M%S`
  echo time: $now_time > version.txt
  echo branch: ${CI_COMMIT_REF_NAME} >> version.txt
}
# 构建docker镜像
function build_docker_image() {
  log_version
  foramt_image_version
  if [ -z "$docker_file_name" ]; then
    docker build -t ${APP_IMAGE}:$image_version . || exit 1
  else
    docker build -f $docker_file_name -t ${APP_IMAGE}:$image_version . || exit 1
  fi
  # 正式版本构建后，清除release版本
  tags_reg='^[0-9]+.[0-9]+.[0-9]+$'
  if [[ "$CI_COMMIT_REF_NAME" =~ $tags_reg ]]; then
    echo "开始清理release镜像"
    clear_release_image
  fi
}
# 主流程
if [ -z "$cmd" ]; then
  echo "命令不能为空"
  exit 1
elif [ "$cmd" == "build" ]; then
  echo "build..."
  build_docker_image
elif [ "$cmd" == "build_java" ]; then
  echo "build java..."
  # 利用maven镜像打包程序
  echo "清理compile目录"
  rm -rf /compile/* && rm -rf /compile/.*
  echo "复制文件到打包目录/compile"
  cp -rf . /compile
  echo "开始打包"
  docker run -i --rm --name maven_build -v /compile:/usr/src/app -v /huansi/maven/repository:/usr/share/maven/ref -w /usr/src/app 47.110.145.204:8084/huansi/maven:3-jdk-$JDK_VERSION mvn clean package || exit 1
  echo "复制打包文件到当前目录下"
  cp -rf /compile/target .
  build_docker_image
elif [ "$cmd" == "push" ]; then
  echo "push..."
  foramt_image_version
  docker push ${APP_IMAGE}:$image_version
elif [ "$cmd" == "push_ali" ]; then
  echo "push_ali..."
  foramt_image_version
  docker tag ${APP_IMAGE}:$image_version ${ALI_IMAGE}:$image_version || exit 1
  docker push ${ALI_IMAGE}:$image_version || exit 1
else
  echo "无效命令:$cmd"
  exit 1
fi
